# SSL Metrics Git Productivity

> Proof of Concept: Measuring the productivity of teams that use Git

[![Publish to PyPi](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-productivity/actions/workflows/pypi.yml/badge.svg)](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-productivity/actions/workflows/pypi.yml)
